@@ -4,27 +4,17 @@
   
 ### Unit tests for chkSpectra.Spectra2D
 load("tiny2D.RData")
-
 tiny2D_NAc <- tiny2D
 tiny2D_NAc$data[[1]][,4] <- NA # single spectrum with col of NAs
+tiny2D_NAc$data[[2]][,3] <- NA 
 
-# chkSpectra detects mismatched col NAs
-expect_error(chkSpectra(tiny2D_NAc), "NAs are present in the data but differ between samples")
 tiny2D_NAr <- tiny2D
 tiny2D_NAr$data[[1]][3,] <- NA # single spectrum with row of NAs
+# chkSpectra detects mismatched col NAs
+expect_error(chkSpectra(tiny2D_NAc), "NAs are present in the data but differ between samples")
 
 # chkSpectra detects mismatched row NAs
 expect_error(chkSpectra(tiny2D_NAr), "NAs are present in the data but differ between samples")
-tiny2D_NAc$data[[2]][,4] <- NA 
-tiny2D_NAc$data[[3]][,4] <- NA 
-
-# .findNA reports col NAs correctly
-expect_equal(.findNA(tiny2D_NAc)$colNA, 4)
-tiny2D_NAr$data[[2]][3,] <- NA 
-tiny2D_NAr$data[[3]][3,] <- NA 
-
-# .findNA reports row NAs correctly"
-expect_equal(.findNA(tiny2D_NAr)$rowNA, 3)
 
 tiny2D_NAmr <- tiny2D
 M <- tiny2D_NAmr$data[[1]]
